@@ -48,10 +48,11 @@ class DocumentFileRepository:
             return (file for file in self.dir_path.iterdir() if file.is_file() and file.suffix != '.pdef')
 
     def list(self) -> set[models.Document]:
-        files = list(self._list_files())
+        files = list(filter(lambda f: not self._doc_path_filter or str(f.resolve()) in self._doc_path_filter,
+                            self._list_files()))
         docs = process_map(self._read_file, files, desc=f"Reading documents in '{self.dir_path}'",
                            unit='doc', total=len(files), max_workers=os.cpu_count())
-        return set(filter(lambda d: d and (not self._doc_path_filter or d.path in self._doc_path_filter), docs))
+        return set(filter(None, docs))
 
     def _read_file(self, file):
         if file.suffix == '.pdf':
